# RepHunt

RepHunt - is a simple console app for those, who want to increase their
reputation on any of the sites, that are included in the Stack Exchange:
- stackoverflow
- serverfault
- superuser
- meta
- webapps
- gaming
- webmasters
- cooking
- gamedev
- photo
- stats
- math
- diy
- gis
- tex
- askubuntu

## Installation

WIP

## Usage

WIP

## Documentation

WIP

```bash
rephunt.py -h
```

## License
[MIT](https://choosealicense.com/licenses/mit/)